pub struct ActorMeshId(/* private fields */);Expand description
Identifies an actor mesh.
Implementations
Sourceimpl ActorMeshId
impl ActorMeshId
Sourcepub fn new(uid: Uid, label: Option<Label>) -> Self
pub fn new(uid: Uid, label: Option<Label>) -> Self
Create a mesh id with explicit uid and label.
Sourcepub fn instance(label: Label) -> Self
pub fn instance(label: Label) -> Self
Create an instance mesh id with a random uid and the given label.
Sourcepub fn display_label(&self) -> Option<&Label>
pub fn display_label(&self) -> Option<&Label>
Returns the human-facing label for this mesh id.
Telemetry uses this for given_name.
Sourcepub fn resource_id(&self) -> &ResourceId
pub fn resource_id(&self) -> &ResourceId
Returns the inner ResourceId.
Sourcepub fn default_instance_label() -> &'static str
pub fn default_instance_label() -> &'static str
Returns the default instance label for this mesh id type.